package com.hardkernel.odroid;

import android.app.Activity;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.CompoundButton;
import android.widget.CompoundButton.OnCheckedChangeListener;
import android.widget.EditText;
import android.widget.ProgressBar;
import android.widget.TextView;

public class ADCActivity extends Activity {
	private CheckBox mADCDriverEnable;
	private TextView mSamplingRateText;
	private EditText mSamplingRate;
	private Button mChangeSamplingRate;
	private ProgressBar mVoltage;
	private Handler mHandler;
	private int mSamplingRateMilisec;
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        mADCDriverEnable = (CheckBox)findViewById(R.id.cb_enable);
        mSamplingRate = (EditText)findViewById(R.id.et_samplingrate);
        mSamplingRateText = (TextView)findViewById(R.id.tv_samplingratetext);
        mChangeSamplingRate = (Button)findViewById(R.id.btn_change);
        mVoltage = (ProgressBar)findViewById(R.id.pb_voltage);
        
        if (checkNode() == 0) {
        	mADCDriverEnable.setVisibility(View.GONE);
        	mSamplingRateText.setVisibility(View.GONE);
        	mSamplingRate.setVisibility(View.GONE);
        	mChangeSamplingRate.setVisibility(View.GONE);
        } else {
        	mADCDriverEnable.setVisibility(View.VISIBLE);
        	mSamplingRateText.setVisibility(View.VISIBLE);
        	mSamplingRate.setVisibility(View.VISIBLE);
        	mChangeSamplingRate.setVisibility(View.VISIBLE);
        	
        	mSamplingRate.setText(readSamplingRate() + "");
        }
        
        int state = getState();
        if (state == 1) {
        	mADCDriverEnable.setChecked(true);
        	update(true);
        } else {
        	mADCDriverEnable.setChecked(false);
        	update(false);
        	}
        
        mADCDriverEnable.setOnCheckedChangeListener(new OnCheckedChangeListener() {

			@Override
			public void onCheckedChanged(CompoundButton buttonView,
					boolean isChecked) {
				// TODO Auto-generated method stub
				if (isChecked)
					setState(1);
				else
					setState(0);
				update(isChecked);
			}
        	
        });
        
        mChangeSamplingRate.setOnClickListener(new OnClickListener() {

			@Override
			public void onClick(View v) {
				// TODO Auto-generated method stub
				int value = Integer.parseInt(mSamplingRate.getText().toString());
				if (value > 0) {
					setSamplingRate(mSamplingRate.getText().toString());
					mSamplingRate.setText(readSamplingRate() + "");
					mHandler.sendEmptyMessageDelayed(0, mSamplingRateMilisec);
				}
			}
        	
        });
        
        mHandler = new Handler() {

            @Override
            public void handleMessage(Message msg) {
                // TODO Auto-generated method stub
                super.handleMessage(msg);
                sendEmptyMessageDelayed(0, mSamplingRateMilisec);
                mVoltage.setProgress(readVoltage());
            }

        };
        mHandler.sendEmptyMessage(1);
    }
    
    private void update(boolean enable) {
    	if (enable) {
				mSamplingRateText.setEnabled(true);
		   mSamplingRate.setEnabled(true);
		   mChangeSamplingRate.setEnabled(true);
		  } else {
			  mSamplingRateText.setEnabled(false);
			  mSamplingRate.setEnabled(false);
			  mChangeSamplingRate.setEnabled(false);
		}
    }
    
   static {
  	  System.loadLibrary("ADCDriverSysfs");
    	}
    
  	native int checkNode();
  	native int getState();
  	native void setState(int enable);
  	native int readSamplingRate();
  	native void setSamplingRate(String value);
  	native int readVoltage();
}